package com.jpattern.orm.generator.wrapper;

/**
 * 
 * A wrapper to a specific type. This is needed to convert a value returned by the ResultSet
 * to a desired type.
 * T is the class of the desired type.
 * R is the class type of the related field in the ResultSet that will be used to perform read/write operations.
 * Valid Class type for R are:
 * 
 * byte[].class
 * Object.class
 * String.class
 * 
 * java.io.InputStream.class
 * java.io.Reader.class
 * 
 * java.math.BigDecimal.class
 * 
 * java.sql.Array.class
 * java.sql.Blob.class
 * java.sql.Clob.class
 * java.sql.Date.class
 * java.sql.NClob.class
 * java.sql.Ref.class
 * java.sql.RowId.class
 * java.sql.SQLXML.class
 * java.sql.Time.class
 * java.sql.Timestamp.class
 * 
 * java.net.URL.class
 * 
 * @author Francesco Cina'
 *
 * Mar 27, 2012
 */
public interface TypeWrapper<T, R> {

	Class<R> resultSetTypeToUse();

	Class<T> wrapperClass();

	T wrap(R value);

	R unWrap(T value);

}
