package com.jpattern.orm.query;

import java.util.List;

import com.jpattern.orm.classtool.IOrmClassToolMap;
import com.jpattern.orm.generator.ResultSetMethodHelper;
import com.jpattern.orm.generator.wrapper.WrapperTypeList;
import com.jpattern.orm.query.clause.OrmSetClause;
import com.jpattern.orm.query.clause.OrmWhere;
import com.jpattern.orm.query.clause.SetClause;
import com.jpattern.orm.query.clause.Where;
import com.jpattern.orm.session.SessionSqlPerformer;
import com.jpattern.orm.session.SqlPerformer;

/**
 * 
 * @author Francesco Cina
 *
 * 10/lug/2011
 */
public class OrmUpdateQuery implements UpdateQuery, INameSolverConsumer {

	private final SetClause<UpdateQuery> set = new OrmSetClause<UpdateQuery>(this);
	private final Where<UpdateQuery> whereExpression = new OrmWhere<UpdateQuery>(this);
	//	private INameSolver nameSolver = new NullNameSolver();
	private int queryTimeout = 0;
	private final Class<?> clazz;
	private final IOrmClassToolMap ormClassToolMap;
	private final SessionSqlPerformer session;
	private final ResultSetMethodHelper rsMethodHelper;

	public OrmUpdateQuery(Class<?> clazz, IOrmClassToolMap ormClassToolMap, SessionSqlPerformer session, ResultSetMethodHelper rsMethodHelper) {
		this.clazz = clazz;
		this.ormClassToolMap = ormClassToolMap;
		this.session = session;
		this.rsMethodHelper = rsMethodHelper;
	}

	@Override
	public Where<UpdateQuery> where() {
		return whereExpression;
	}

	@Override
	public int perform() {
		final List<Object> values = new WrapperTypeList(rsMethodHelper);
		appendValues(values);
		final SqlPerformer sqlExec = session.sqlPerformer();
		sqlExec.setQueryTimeout(getQueryTimeout());
		return sqlExec.update(renderSql(), values.toArray());
	}

	@Override
	public void appendValues(List<Object> values) {
		set.appendValues(values);
		whereExpression.appendValues(values);
	}

	@Override
	public UpdateQuery setQueryTimeout(int queryTimeout) {
		this.queryTimeout = queryTimeout;
		return this;
	}

	@Override
	public int getQueryTimeout() {
		return queryTimeout;
	}

	@Override
	public void setNameSolver(INameSolver nameSolver) {
		//		this.nameSolver = nameSolver;
		whereExpression.setNameSolver(nameSolver);
		set.setNameSolver(nameSolver);
	}

	@Override
	public String renderSql() {
		final StringBuilder StringBuilder = new StringBuilder();
		renderSql(StringBuilder);
		return StringBuilder.toString();
	}

	@Override
	public void renderSql(StringBuilder StringBuilder) {
		StringBuilder.append("UPDATE ");
		StringBuilder.append(ormClassToolMap.getOrmClassTool(clazz).getClassMapper().getTableMap().getTableNameWithSchema() );
		StringBuilder.append(" ");
		set().renderSql(StringBuilder);
		where().renderSql(StringBuilder);
	}

	@Override
	public SetClause<UpdateQuery> set() {
		return set;
	}

}
