package com.jpattern.orm.query;

import java.util.List;

import com.jpattern.orm.query.clause.SetClause;
import com.jpattern.orm.query.clause.Where;

/**
 * 
 * @author Francesco Cina
 *
 * 10/lug/2011
 */
public interface UpdateQuery extends IQueryRoot, IRenderableSqlObject {

	/**
	 * Create or modify the "SET" clause of the update statement.
	 * @return
	 */
	SetClause<UpdateQuery> set();

	/**
	 * Create or modify the "WHERE" clause of the statement.
	 * @return
	 */
	Where<UpdateQuery> where();

	/**
	 * Perform the update and return the number of affected rows.
	 * @return
	 */
	int perform();

	/**
	 * Append to the list all the values of the expression's elements
	 * @return
	 */
	void appendValues(List<Object> values);

	/**
	 * Set the query timeout for the query.
	 */
	UpdateQuery setQueryTimeout(int queryTimeout);

	/**
	 * Return the query timeout for the query.
	 */
	int getQueryTimeout();

}
