package com.jpattern.orm.session.datasource;

import javax.sql.DataSource;

import com.jpattern.logger.ILogger;
import com.jpattern.orm.logger.OrmLogger;
import com.jpattern.orm.session.SessionProvider;
import com.jpattern.orm.session.SessionStrategy;

/**
 * 
 * @author Francesco Cina
 *
 * 21/mag/2011
 */
public class DataSourceSessionProvider implements SessionProvider {

	private final ThreadLocal<IConnection> threadLocalConnection = new ThreadLocal<IConnection>();
	private final DataSource dataSource;
	private final ILogger logger = OrmLogger.getOrmLogger(this.getClass());

	public DataSourceSessionProvider(DataSource dataSource) {
		this.dataSource = dataSource;
	}

	@Override
	public SessionStrategy getSessionStrategy() {
		return new DataSourceSessionStrategy(this);
	}

	final IConnection getConnection(boolean readOnly, IConnectionCaller connectionCaller) {
		this.logger.debug("getConnection", "new connection asked by " + connectionCaller );
		IConnection conn = this.threadLocalConnection.get();
		if ((conn==null) || !conn.isValid()) {
			this.logger.info("getConnection", "no valid connections found, a new one will be created");
			conn = new DataSourceConnection(this.dataSource, readOnly);
			this.threadLocalConnection.set(conn);
		}
		conn.addCaller(connectionCaller);
		return conn;
	}

}
